PyRuntimeType

Trait PyRuntimeType 

pub trait PyRuntimeType {
    // Required method
    fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>;
}
Trait for Rust types that can be converted to Python type objects at runtime.

This trait is used by type_alias! to create runtime type aliases that can be imported from Python. Unlike PyStubType which is used for stub file generation, this trait is only needed when you want to register type aliases at runtime.

Implementing for Custom Types

For #[pyclass] types, use py.get_type::<Self>():

use pyo3::prelude::*;
use pyo3_stub_gen::runtime::PyRuntimeType;

#[pyclass]
struct MyClass;

impl PyRuntimeType for MyClass {
    fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>> {
        Ok(py.get_type::<Self>().into_any())
    }
}

Note

This trait is automatically implemented for common Rust types (primitives, collections, etc.) and for types that use #[gen_stub_pyclass] derive macro.

Required Methods

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Returns the Python type object for this Rust type.

Examples
  • i32<class 'int'>
  • String<class 'str'>
  • Option<T>T | None
  • Vec<T>list

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl PyRuntimeType for &str

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Cow<'_, str>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Cow<'_, OsStr>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Cow<'_, [u8]>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for bool

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for char

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for f32

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for f64

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for i8

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for i16

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for i32

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for i64

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for i128

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for isize

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for u8

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for u16

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for u32

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for u64

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for u128

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for ()

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for usize

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for String

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Duration

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for OsStr

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for OsString

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PathBuf

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for SystemTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for NaiveDate

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for NaiveDateTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for NaiveTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for FixedOffset

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Utc

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Duration

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Complex32

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Complex64

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for CompareOp

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Date

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Decimal

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Duration

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for NotNan<f32>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for NotNan<f64>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for OffsetDateTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for OrderedFloat<f32>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for OrderedFloat<f64>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PrimitiveDateTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyAny

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyArithmeticError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyArrayDescr

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyAssertionError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyAttributeError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBackedBytes

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBackedStr

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBaseException

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBlockingIOError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBool

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBrokenPipeError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBufferError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyByteArray

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBytes

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyBytesWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyChildProcessError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyComplex

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyConnectionAbortedError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyConnectionError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyConnectionRefusedError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyConnectionResetError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyDate

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyDateTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyDelta

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyDeprecationWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyDict

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyEOFError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyEncodingWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyEnvironmentError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyException

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyFileExistsError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyFileNotFoundError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyFloat

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyFloatingPointError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyFutureWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyGeneratorExit

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyIOError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyImportError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyImportWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyIndexError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyInt

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyInterruptedError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyIsADirectoryError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyKeyError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyKeyboardInterrupt

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyList

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyLookupError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyMemoryError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyModuleNotFoundError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyNameError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyNotADirectoryError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyNotImplementedError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyOSError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyOverflowError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyPendingDeprecationWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyPermissionError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyProcessLookupError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyRecursionError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyReferenceError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyResourceWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyRuntimeError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyRuntimeWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PySet

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PySlice

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyStopAsyncIteration

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyStopIteration

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyString

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PySyntaxError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PySyntaxWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PySystemError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PySystemExit

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyTimeoutError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyTuple

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyType

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyTypeError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyTzInfo

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUnboundLocalError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUnicodeDecodeError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUnicodeEncodeError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUnicodeError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUnicodeTranslateError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUnicodeWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUntypedArray

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyUserWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyValueError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyWarning

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for PyZeroDivisionError

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for Time

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for UtcDateTime

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl PyRuntimeType for UtcOffset

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<Key, Value> PyRuntimeType for BTreeMap<Key, Value>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<Key, Value, State> PyRuntimeType for HashMap<Key, Value, State>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<Key, Value, State> PyRuntimeType for IndexMap<Key, Value, State>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<L: PyRuntimeType, R: PyRuntimeType> PyRuntimeType for Either<L, R>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1> PyRuntimeType for (T1,)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2> PyRuntimeType for (T1, T2)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2, T3> PyRuntimeType for (T1, T2, T3)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2, T3, T4> PyRuntimeType for (T1, T2, T3, T4)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2, T3, T4, T5> PyRuntimeType for (T1, T2, T3, T4, T5)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2, T3, T4, T5, T6> PyRuntimeType for (T1, T2, T3, T4, T5, T6)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2, T3, T4, T5, T6, T7> PyRuntimeType for (T1, T2, T3, T4, T5, T6, T7)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8> PyRuntimeType for (T1, T2, T3, T4, T5, T6, T7, T8)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T1, T2, T3, T4, T5, T6, T7, T8, T9> PyRuntimeType for (T1, T2, T3, T4, T5, T6, T7, T8, T9)

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T> PyRuntimeType for BTreeSet<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T> PyRuntimeType for Vec<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T> PyRuntimeType for IndexSet<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T, D> PyRuntimeType for PyArray<T, D>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T, D> PyRuntimeType for PyReadonlyArray<'_, T, D>
where T: Element, D: Dimension,

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T, D> PyRuntimeType for PyReadwriteArray<'_, T, D>
where T: Element, D: Dimension,

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T, State> PyRuntimeType for HashSet<T, State>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T, const N: usize> PyRuntimeType for [T; N]

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType + PyClass> PyRuntimeType for PyRef<'_, T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType + PyClass<Frozen = False>> PyRuntimeType for PyRefMut<'_, T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType> PyRuntimeType for Option<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType> PyRuntimeType for &T

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType> PyRuntimeType for Box<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType> PyRuntimeType for Rc<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType> PyRuntimeType for Arc<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType> PyRuntimeType for Bound<'_, T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType> PyRuntimeType for Py<T>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<T: PyRuntimeType, E> PyRuntimeType for Result<T, E>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Source

impl<Tz: TimeZone> PyRuntimeType for DateTime<Tz>

Source

fn runtime_type_object(py: Python<'_>) -> PyResult<Bound<'_, PyAny>>

Implementors